summaryrefslogtreecommitdiffstats
path: root/winit/src/lib.rs
diff options
context:
space:
mode:
Diffstat (limited to 'winit/src/lib.rs')
-rw-r--r--winit/src/lib.rs15
1 files changed, 7 insertions, 8 deletions
diff --git a/winit/src/lib.rs b/winit/src/lib.rs
index 3619cde8..3c11b72a 100644
--- a/winit/src/lib.rs
+++ b/winit/src/lib.rs
@@ -5,7 +5,7 @@
//! `iced_winit` offers some convenient abstractions on top of [`iced_runtime`]
//! to quickstart development when using [`winit`].
//!
//! It exposes a renderer-agnostic [`Application`] trait that can be implemented
//! and then run with a simple call. The use of this trait is optional.
//!
//! Additionally, a [`conversion`] module is available for users that decide to
@@ -24,24 +24,23 @@ pub use iced_runtime::core;
pub use iced_runtime::futures;
pub use winit;
-#[cfg(feature = "multi-window")]
-pub mod multi_window;
-
-#[cfg(feature = "application")]
-pub mod application;
pub mod clipboard;
pub mod conversion;
pub mod settings;
+#[cfg(feature = "program")]
+pub mod program;
+
#[cfg(feature = "system")]
pub mod system;
mod error;
mod proxy;
-#[cfg(feature = "application")]
-pub use application::Application;
pub use clipboard::Clipboard;
pub use error::Error;
pub use proxy::Proxy;
pub use settings::Settings;
+
+#[cfg(feature = "program")]
+pub use program::Program;
@@ -5,7 +5,7 @@
//! to quickstart development when using [`winit`].
//!
-//! It exposes a renderer-agnostic [`Application`] trait that can be implemented
+//! It exposes a renderer-agnostic [`Program`] trait that can be implemented
//! and then run with a simple call. The use of this trait is optional.
//!